@@ -106,7 +106,7 @@ To configure signal polarities or quadrature directions, some enumerations are d
     trsi.quadrature_direction = Direction.REVERSE
 """
 
-__version__ = "1.4.0"
+__version__ = "1.4.1"
 
 import logging
 import asyncio
@@ -287,8 +287,8 @@ class TRSInterface():
             for cb in self._error_callbacks:
                 cb(msg)
         except BufferError:
-            # Receive buffer filled. Abort and try to recover.
-            self._log.error("Received message too large for buffer.")
+            # Message size limit exceeded, abort and try to recover.
+            self._log.error("Received message exceeded maximum size limit.")
             self.stop()
             # Schedule next check
             self._loop.call_later(self.read_interval, self._schedule_reads)
